# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: araali_api_service.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x18\x61raali_api_service.proto\x12\x12\x61raali_api_service\x1a\x1fgoogle/protobuf/timestamp.proto\")\n\x06Tenant\x12\n\n\x02id\x18\x01 \x01(\t\x12\x13\n\x0b\x61\x64min_email\x18\x02 \x01(\t\"\x82\x01\n\nAraaliUser\x12\r\n\x05\x65mail\x18\x01 \x01(\t\x12\x31\n\x04role\x18\x02 \x01(\x0e\x32#.araali_api_service.AraaliUser.Role\x12\x15\n\ris_site_admin\x18\x03 \x01(\x08\"\x1b\n\x04Role\x12\t\n\x05\x41\x44MIN\x10\x00\x12\x08\n\x04USER\x10\x01\"A\n\x13\x43reateTenantRequest\x12*\n\x06tenant\x18\x01 \x01(\x0b\x32\x1a.araali_api_service.Tenant\"{\n\x14\x43reateTenantResponse\x12\x37\n\x08response\x18\x01 \x01(\x0b\x32%.araali_api_service.AraaliAPIResponse\x12*\n\x06tenant\x18\x02 \x01(\x0b\x32\x1a.araali_api_service.Tenant\"A\n\x13\x44\x65leteTenantRequest\x12*\n\x06tenant\x18\x01 \x01(\x0b\x32\x1a.araali_api_service.Tenant\"j\n\x0e\x41\x64\x64UserRequest\x12*\n\x06tenant\x18\x01 \x01(\x0b\x32\x1a.araali_api_service.Tenant\x12,\n\x04user\x18\x02 \x01(\x0b\x32\x1e.araali_api_service.AraaliUser\"m\n\x11\x44\x65leteUserRequest\x12*\n\x06tenant\x18\x01 \x01(\x0b\x32\x1a.araali_api_service.Tenant\x12,\n\x04user\x18\x02 \x01(\x0b\x32\x1e.araali_api_service.AraaliUser\"\x99\x01\n\x11\x41raaliAPIResponse\x12>\n\x04\x63ode\x18\x01 \x01(\x0e\x32\x30.araali_api_service.AraaliAPIResponse.ReturnCode\x12\x0f\n\x07message\x18\x02 \x01(\t\"3\n\nReturnCode\x12\x0b\n\x07SUCCESS\x10\x00\x12\x0b\n\x07\x46\x41ILURE\x10\x01\x12\x0b\n\x07UNKNOWN\x10\x02\"i\n\tTimeSlice\x12.\n\nstart_time\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12,\n\x08\x65nd_time\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\"\x7f\n\x0b\x41ssetFilter\x12\x16\n\x0elist_active_vm\x18\x01 \x01(\x08\x12\x18\n\x10list_inactive_vm\x18\x02 \x01(\x08\x12\x1d\n\x15list_active_container\x18\x03 \x01(\x08\x12\x1f\n\x17list_inactive_container\x18\x04 \x01(\x08\"\xb8\x01\n\x11ListAssetsRequest\x12*\n\x06tenant\x18\x01 \x01(\x0b\x32\x1a.araali_api_service.Tenant\x12\x0c\n\x04zone\x18\x02 \x01(\t\x12\x0b\n\x03\x61pp\x18\x03 \x01(\t\x12+\n\x04time\x18\x04 \x01(\x0b\x32\x1d.araali_api_service.TimeSlice\x12/\n\x06\x66ilter\x18\x05 \x01(\x0b\x32\x1f.araali_api_service.AssetFilter\"x\n\x12ListAssetsResponse\x12\x37\n\x08response\x18\x01 \x01(\x0b\x32%.araali_api_service.AraaliAPIResponse\x12)\n\x06\x61ssets\x18\x02 \x03(\x0b\x32\x19.araali_api_service.Asset\"$\n\x0c\x43\x61pabilities\x12\x14\n\x0c\x63\x61pabilities\x18\x01 \x03(\t\"\xdb\x05\n\x05\x41sset\x12\x11\n\thost_name\x18\x01 \x01(\t\x12\x12\n\nip_address\x18\x02 \x01(\t\x12\x0c\n\x04uuid\x18\x03 \x01(\t\x12\r\n\x05image\x18\x04 \x01(\t\x12\x0c\n\x04zone\x18\x05 \x01(\t\x12\x0c\n\x04\x61pps\x18\x06 \x03(\t\x12\x33\n\x05state\x18\x07 \x01(\x0e\x32$.araali_api_service.Asset.AssetState\x12\x37\n\nasset_type\x18\x08 \x01(\x0e\x32#.araali_api_service.Asset.AssetType\x12:\n\x0fvulnerabilities\x18\t \x03(\x0b\x32!.araali_api_service.Vulnerability\x12\x31\n\x04mode\x18\n \x01(\x0e\x32#.araali_api_service.Asset.AssetMode\x12\x0f\n\x07os_name\x18\x0b \x01(\t\x12\x10\n\x08iam_role\x18\x0c \x01(\t\x12\x19\n\x11\x64ocker_privileged\x18\r \x01(\x08\x12\x32\n\x06\x64ocker\x18\x0e \x01(\x0b\x32 .araali_api_service.CapabilitiesH\x00\x12\x36\n\ncontainerd\x18\x0f \x01(\x0b\x32 .araali_api_service.CapabilitiesH\x00\"3\n\nAssetState\x12\x0b\n\x07\x44\x45LETED\x10\x00\x12\n\n\x06\x41\x43TIVE\x10\x01\x12\x0c\n\x08INACTIVE\x10\x02\"B\n\tAssetType\x12\x11\n\rUNKNOWN_ASSET\x10\x00\x12\x13\n\x0fVIRTUAL_MACHINE\x10\x01\x12\r\n\tCONTAINER\x10\x02\"b\n\tAssetMode\x12\x07\n\x03TAP\x10\x00\x12\n\n\x06INLINE\x10\x01\x12\x1f\n\x1bTRANSITIONING_TAP_TO_INLINE\x10\x02\x12\x1f\n\x1bTRANSITIONING_INLINE_TO_TAP\x10\x03\x42\x0e\n\x0c\x63\x61pabilities\"\xb6\x01\n\rVulnerability\x12\x14\n\x0cpackage_name\x18\x01 \x01(\t\x12\x0e\n\x06\x63ve_id\x18\x02 \x03(\t\x12<\n\x08severity\x18\x03 \x01(\x0e\x32*.araali_api_service.Vulnerability.Severity\"A\n\x08Severity\x12\x08\n\x04NONE\x10\x00\x12\x07\n\x03LOW\x10\x01\x12\n\n\x06MEDIUM\x10\x02\x12\x08\n\x04HIGH\x10\x03\x12\x0c\n\x08\x43RITICAL\x10\x04\"\x9d\x02\n\x0b\x41lertFilter\x12\x13\n\x0bopen_alerts\x18\x01 \x01(\x08\x12\x15\n\rclosed_alerts\x18\x02 \x01(\x08\x12\x18\n\x10perimeter_egress\x18\x03 \x01(\x08\x12\x19\n\x11perimeter_ingress\x18\x04 \x01(\x08\x12\x1e\n\x16home_non_araali_egress\x18\x05 \x01(\x08\x12\x1f\n\x17home_non_araali_ingress\x18\x06 \x01(\x08\x12\x18\n\x10\x61raali_to_araali\x18\x07 \x01(\x08\x12\x17\n\x0flist_all_alerts\x18\x08 \x01(\x08\x12+\n\x04time\x18\t \x01(\x0b\x32\x1d.araali_api_service.TimeSlice\x12\x0c\n\x04zone\x18\n \x01(\t\"\x95\x01\n\x11ListAlertsRequest\x12*\n\x06tenant\x18\x01 \x01(\x0b\x32\x1a.araali_api_service.Tenant\x12/\n\x06\x66ilter\x18\x02 \x01(\x0b\x32\x1f.araali_api_service.AlertFilter\x12\r\n\x05\x63ount\x18\x03 \x01(\x05\x12\x14\n\x0cpaging_token\x18\x04 \x01(\t\"\x8c\x01\n\x12ListAlertsResponse\x12\x37\n\x08response\x18\x01 \x01(\x0b\x32%.araali_api_service.AraaliAPIResponse\x12\'\n\x05links\x18\x02 \x03(\x0b\x32\x18.araali_api_service.Link\x12\x14\n\x0cpaging_token\x18\x03 \x01(\t\"\xb7\x01\n\x0e\x41raaliEndpoint\x12\x0c\n\x04zone\x18\x01 \x01(\t\x12\x0b\n\x03\x61pp\x18\x02 \x01(\t\x12\x14\n\x0cunmapped_app\x18\x03 \x01(\t\x12\x11\n\tnamespace\x18\x04 \x01(\t\x12\x0b\n\x03pod\x18\x05 \x01(\t\x12\x16\n\x0e\x63ontainer_name\x18\x06 \x01(\t\x12\x0f\n\x07process\x18\x07 \x01(\t\x12\x13\n\x0b\x62inary_name\x18\x08 \x01(\t\x12\x16\n\x0eparent_process\x18\t \x01(\t\"*\n\x06Subnet\x12\x0e\n\x06subnet\x18\x01 \x01(\t\x12\x10\n\x08net_mask\x18\x02 \x01(\r\"E\n\x17NonAraaliClientEndpoint\x12*\n\x06subnet\x18\x01 \x01(\x0b\x32\x1a.araali_api_service.Subnet\"\x81\x01\n\x17NonAraaliServerEndpoint\x12\x15\n\x0b\x64ns_pattern\x18\x01 \x01(\tH\x00\x12,\n\x06subnet\x18\x02 \x01(\x0b\x32\x1a.araali_api_service.SubnetH\x00\x12\x10\n\x08\x64st_port\x18\r \x01(\rB\x0f\n\rdns_or_subnet\"\xb5\x02\n\x11NonAraaliEndpoint\x12=\n\x06\x63lient\x18\x01 \x01(\x0b\x32+.araali_api_service.NonAraaliClientEndpointH\x00\x12=\n\x06server\x18\x02 \x01(\x0b\x32+.araali_api_service.NonAraaliServerEndpointH\x00\x12K\n\x0e\x65ndpoint_group\x18\x03 \x01(\x0e\x32\x33.araali_api_service.NonAraaliEndpoint.EndpointGroup\x12\x14\n\x0corganization\x18\x04 \x01(\t\"7\n\rEndpointGroup\x12\x11\n\rUNKNOWN_GROUP\x10\x00\x12\t\n\x05WORLD\x10\x01\x12\x08\n\x04HOME\x10\x02\x42\x06\n\x04info\"\x85\x01\n\x08\x45ndPoint\x12\x34\n\x06\x61raali\x18\x01 \x01(\x0b\x32\".araali_api_service.AraaliEndpointH\x00\x12;\n\nnon_araali\x18\x02 \x01(\x0b\x32%.araali_api_service.NonAraaliEndpointH\x00\x42\x06\n\x04info\"\xca\x01\n\tAlertInfo\x12 \n\x18\x63ommunication_alert_type\x18\x01 \x01(\t\x12\x1a\n\x12process_alert_type\x18\x02 \x01(\t\x12\x15\n\rre_open_count\x18\x03 \x01(\r\x12\x34\n\x06status\x18\x04 \x01(\x0e\x32$.araali_api_service.AlertInfo.Status\"2\n\x06Status\x12\x12\n\x0eUNKNOWN_STATUS\x10\x00\x12\x08\n\x04OPEN\x10\x01\x12\n\n\x06\x43LOSED\x10\x02\"5\n\x05Ports\x12\x14\n\x0c\x61\x63tive_ports\x18\x01 \x03(\r\x12\x16\n\x0einactive_ports\x18\x02 \x03(\r\"\xb8\x04\n\x04Link\x12,\n\x06\x63lient\x18\x01 \x01(\x0b\x32\x1c.araali_api_service.EndPoint\x12,\n\x06server\x18\x02 \x01(\x0b\x32\x1c.araali_api_service.EndPoint\x12\x39\n\tdirection\x18\x03 \x01(\x0e\x32&.araali_api_service.Link.LinkDirection\x12-\n\ttimestamp\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x11\n\tunique_id\x18\x05 \x01(\t\x12,\n\x05state\x18\x06 \x01(\x0e\x32\x1d.araali_api_service.LinkState\x12(\n\x05ports\x18\x07 \x01(\x0b\x32\x19.araali_api_service.Ports\x12\x33\n\nalert_info\x18\x08 \x01(\x0b\x32\x1d.araali_api_service.AlertInfoH\x00\x12\x35\n\x0bpolicy_info\x18\t \x01(\x0b\x32\x1e.araali_api_service.PolicyInfoH\x00\"\x8a\x01\n\rLinkDirection\x12\x15\n\x11UNKNOWN_DIRECTION\x10\x00\x12\x16\n\x12NON_ARAALI_INGRESS\x10\x01\x12\x12\n\x0e\x41RAALI_INGRESS\x10\x02\x12\x15\n\x11NON_ARAALI_EGRESS\x10\x03\x12\x11\n\rARAALI_EGRESS\x10\x04\x12\x0c\n\x08INTERNAL\x10\x05\x42\x06\n\x04info\"V\n\nPolicyInfo\x12\x15\n\rtemplate_name\x18\x01 \x01(\t\x12\x15\n\rtemplate_user\x18\x02 \x01(\t\x12\x1a\n\x12policy_skip_reason\x18\x03 \x01(\t\"\x97\x01\n\x10ListLinksRequest\x12*\n\x06tenant\x18\x01 \x01(\x0b\x32\x1a.araali_api_service.Tenant\x12\x0c\n\x04zone\x18\x02 \x01(\t\x12\x0b\n\x03\x61pp\x18\x03 \x01(\t\x12\x0f\n\x07service\x18\x04 \x01(\t\x12+\n\x04time\x18\x05 \x01(\x0b\x32\x1d.araali_api_service.TimeSlice\"u\n\x11ListLinksResponse\x12\x37\n\x08response\x18\x01 \x01(\x0b\x32%.araali_api_service.AraaliAPIResponse\x12\'\n\x05links\x18\x02 \x03(\x0b\x32\x18.araali_api_service.Link\"\xb1\x02\n\x04Lens\x12/\n\x04type\x18\x01 \x01(\x0e\x32!.araali_api_service.Lens.LensType\x12\x0c\n\x04zone\x18\x02 \x01(\t\x12\x0b\n\x03\x61pp\x18\x03 \x01(\t\x12\x0b\n\x03pod\x18\x04 \x01(\t\x12\x16\n\x0e\x63ontainer_name\x18\x05 \x01(\t\x12\x0f\n\x07process\x18\x06 \x01(\t\x12\x16\n\x0eparent_process\x18\x07 \x01(\t\x12\x13\n\x0b\x62inary_name\x18\x08 \x01(\t\x12\x0f\n\x07service\x18\t \x01(\t\"i\n\x08LensType\x12\x10\n\x0cUNKNOWN_LENS\x10\x00\x12\x0c\n\x08ZONE_APP\x10\x01\x12\x0b\n\x07SERVICE\x10\x02\x12\x08\n\x04ZONE\x10\x03\x12\x0b\n\x07PROCESS\x10\x04\x12\r\n\tCONTAINER\x10\x05\x12\n\n\x06TENANT\x10\x06\"]\n\x07Insight\x12\x0e\n\x06reason\x18\x01 \x01(\t\x12\x0b\n\x03url\x18\x02 \x01(\t\x12\r\n\x05\x63ount\x18\x03 \x01(\r\x12&\n\x04lens\x18\x04 \x03(\x0b\x32\x18.araali_api_service.Lens\"O\n\x13ListInsightsRequest\x12*\n\x06tenant\x18\x01 \x01(\x0b\x32\x1a.araali_api_service.Tenant\x12\x0c\n\x04zone\x18\x02 \x01(\t\"~\n\x14ListInsightsResponse\x12\x37\n\x08response\x18\x01 \x01(\x0b\x32%.araali_api_service.AraaliAPIResponse\x12-\n\x08insights\x18\x02 \x03(\x0b\x32\x1b.araali_api_service.Insight\"\xd8\x01\n\x18\x43reateFortifyYamlRequest\x12*\n\x06tenant\x18\x01 \x01(\x0b\x32\x1a.araali_api_service.Tenant\x12\x15\n\rworkload_name\x18\x02 \x01(\t\x12\x0b\n\x03\x66og\x18\x03 \x01(\t\x12\x17\n\x0f\x64isable_upgrade\x18\x04 \x01(\x08\x12\x1b\n\x13\x64isable_enforcement\x18\x05 \x01(\x08\x12\x36\n\tyaml_type\x18\x06 \x01(\x0e\x32#.araali_api_service.FortifyYamlType\"k\n\x19\x43reateFortifyYamlResponse\x12\x37\n\x08response\x18\x01 \x01(\x0b\x32%.araali_api_service.AraaliAPIResponse\x12\x15\n\rworkload_yaml\x18\x02 \x01(\t\"|\n\x16ListFortifyYamlRequest\x12*\n\x06tenant\x18\x01 \x01(\x0b\x32\x1a.araali_api_service.Tenant\x12\x36\n\tyaml_type\x18\x02 \x01(\x0e\x32#.araali_api_service.FortifyYamlType\"e\n\x17ListFortifyYamlResponse\x12\x37\n\x08response\x18\x01 \x01(\x0b\x32%.araali_api_service.AraaliAPIResponse\x12\x11\n\tworkloads\x18\x02 \x03(\t\"]\n\x18\x44\x65leteFortifyYamlRequest\x12*\n\x06tenant\x18\x01 \x01(\x0b\x32\x1a.araali_api_service.Tenant\x12\x15\n\rworkload_name\x18\x02 \x01(\t\"\x8e\x01\n%ListPolicyAndEnforcementStatusRequest\x12*\n\x06tenant\x18\x01 \x01(\x0b\x32\x1a.araali_api_service.Tenant\x12\x0c\n\x04zone\x18\x02 \x01(\t\x12\x0b\n\x03\x61pp\x18\x03 \x01(\t\x12\x0b\n\x03pod\x18\x04 \x01(\t\x12\x11\n\tcontainer\x18\x05 \x01(\t\"M\n&ListPolicyAndEnforcementStatusResponse\x12#\n\x1bpolicy_and_enforcement_yaml\x18\x01 \x01(\t\"\xad\x01\n\rAraaliFwKnobs\x12\x0f\n\x07install\x18\x01 \x01(\x08\x12&\n\x1e\x65nable_process_vulnerabilities\x18\x02 \x01(\x08\x12(\n enable_container_vulnerabilities\x18\x03 \x01(\x08\x12\x19\n\x11\x65nable_flow_dedup\x18\x04 \x01(\x08\x12\x1e\n\x16\x65nable_flow_rate_limit\x18\x05 \x01(\x08\";\n\x18GetFirewallConfigRequest\x12\x11\n\ttenant_id\x18\x01 \x01(\t\x12\x0c\n\x04zone\x18\x02 \x01(\t\"p\n\x1bUpdateFirewallConfigRequest\x12\x11\n\ttenant_id\x18\x01 \x01(\t\x12\x0c\n\x04zone\x18\x02 \x01(\t\x12\x30\n\x05knobs\x18\x03 \x01(\x0b\x32!.araali_api_service.AraaliFwKnobs\"k\n\x16\x46irewallConfigResponse\x12\x11\n\ttenant_id\x18\x02 \x01(\t\x12\x0c\n\x04zone\x18\x03 \x01(\t\x12\x30\n\x05knobs\x18\x04 \x01(\x0b\x32!.araali_api_service.AraaliFwKnobs*Z\n\tLinkState\x12\x12\n\x0e\x42\x41SELINE_ALERT\x10\x00\x12\x12\n\x0e\x44\x45\x46INED_POLICY\x10\x01\x12\x12\n\x0eSNOOZED_POLICY\x10\x02\x12\x11\n\rDENIED_POLICY\x10\x03*U\n\x0f\x46ortifyYamlType\x12\x0b\n\x07UNKNOWN\x10\x00\x12\x14\n\x10HELM_VALUES_FILE\x10\x01\x12\x1f\n\x1bHELM_CONTROLLER_VALUES_FILE\x10\x02\x32\xd9\x0b\n\tAraaliAPI\x12\x63\n\x0c\x63reateTenant\x12\'.araali_api_service.CreateTenantRequest\x1a(.araali_api_service.CreateTenantResponse\"\x00\x12`\n\x0c\x64\x65leteTenant\x12\'.araali_api_service.DeleteTenantRequest\x1a%.araali_api_service.AraaliAPIResponse\"\x00\x12V\n\x07\x61\x64\x64User\x12\".araali_api_service.AddUserRequest\x1a%.araali_api_service.AraaliAPIResponse\"\x00\x12\\\n\ndeleteUser\x12%.araali_api_service.DeleteUserRequest\x1a%.araali_api_service.AraaliAPIResponse\"\x00\x12]\n\nlistAssets\x12%.araali_api_service.ListAssetsRequest\x1a&.araali_api_service.ListAssetsResponse\"\x00\x12]\n\nlistAlerts\x12%.araali_api_service.ListAlertsRequest\x1a&.araali_api_service.ListAlertsResponse\"\x00\x12Z\n\tlistLinks\x12$.araali_api_service.ListLinksRequest\x1a%.araali_api_service.ListLinksResponse\"\x00\x12\x63\n\x0clistInsights\x12\'.araali_api_service.ListInsightsRequest\x1a(.araali_api_service.ListInsightsResponse\"\x00\x12r\n\x11\x63reateFortifyYaml\x12,.araali_api_service.CreateFortifyYamlRequest\x1a-.araali_api_service.CreateFortifyYamlResponse\"\x00\x12l\n\x0flistFortifyYaml\x12*.araali_api_service.ListFortifyYamlRequest\x1a+.araali_api_service.ListFortifyYamlResponse\"\x00\x12j\n\x11\x64\x65leteFortifyYaml\x12,.araali_api_service.DeleteFortifyYamlRequest\x1a%.araali_api_service.AraaliAPIResponse\"\x00\x12\x99\x01\n\x1elistPolicyAndEnforcementStatus\x12\x39.araali_api_service.ListPolicyAndEnforcementStatusRequest\x1a:.araali_api_service.ListPolicyAndEnforcementStatusResponse\"\x00\x12o\n\x11getFirewallConfig\x12,.araali_api_service.GetFirewallConfigRequest\x1a*.araali_api_service.FirewallConfigResponse\"\x00\x12u\n\x14updateFirewallConfig\x12/.araali_api_service.UpdateFirewallConfigRequest\x1a*.araali_api_service.FirewallConfigResponse\"\x00\x42\x43\n\x10proto.araali.apiB\x0f\x41PIServiceProtoP\x01Z\x1cgolang/v2/araali_api_serviceb\x06proto3')

_LINKSTATE = DESCRIPTOR.enum_types_by_name['LinkState']
LinkState = enum_type_wrapper.EnumTypeWrapper(_LINKSTATE)
_FORTIFYYAMLTYPE = DESCRIPTOR.enum_types_by_name['FortifyYamlType']
FortifyYamlType = enum_type_wrapper.EnumTypeWrapper(_FORTIFYYAMLTYPE)
BASELINE_ALERT = 0
DEFINED_POLICY = 1
SNOOZED_POLICY = 2
DENIED_POLICY = 3
UNKNOWN = 0
HELM_VALUES_FILE = 1
HELM_CONTROLLER_VALUES_FILE = 2


_TENANT = DESCRIPTOR.message_types_by_name['Tenant']
_ARAALIUSER = DESCRIPTOR.message_types_by_name['AraaliUser']
_CREATETENANTREQUEST = DESCRIPTOR.message_types_by_name['CreateTenantRequest']
_CREATETENANTRESPONSE = DESCRIPTOR.message_types_by_name['CreateTenantResponse']
_DELETETENANTREQUEST = DESCRIPTOR.message_types_by_name['DeleteTenantRequest']
_ADDUSERREQUEST = DESCRIPTOR.message_types_by_name['AddUserRequest']
_DELETEUSERREQUEST = DESCRIPTOR.message_types_by_name['DeleteUserRequest']
_ARAALIAPIRESPONSE = DESCRIPTOR.message_types_by_name['AraaliAPIResponse']
_TIMESLICE = DESCRIPTOR.message_types_by_name['TimeSlice']
_ASSETFILTER = DESCRIPTOR.message_types_by_name['AssetFilter']
_LISTASSETSREQUEST = DESCRIPTOR.message_types_by_name['ListAssetsRequest']
_LISTASSETSRESPONSE = DESCRIPTOR.message_types_by_name['ListAssetsResponse']
_CAPABILITIES = DESCRIPTOR.message_types_by_name['Capabilities']
_ASSET = DESCRIPTOR.message_types_by_name['Asset']
_VULNERABILITY = DESCRIPTOR.message_types_by_name['Vulnerability']
_ALERTFILTER = DESCRIPTOR.message_types_by_name['AlertFilter']
_LISTALERTSREQUEST = DESCRIPTOR.message_types_by_name['ListAlertsRequest']
_LISTALERTSRESPONSE = DESCRIPTOR.message_types_by_name['ListAlertsResponse']
_ARAALIENDPOINT = DESCRIPTOR.message_types_by_name['AraaliEndpoint']
_SUBNET = DESCRIPTOR.message_types_by_name['Subnet']
_NONARAALICLIENTENDPOINT = DESCRIPTOR.message_types_by_name['NonAraaliClientEndpoint']
_NONARAALISERVERENDPOINT = DESCRIPTOR.message_types_by_name['NonAraaliServerEndpoint']
_NONARAALIENDPOINT = DESCRIPTOR.message_types_by_name['NonAraaliEndpoint']
_ENDPOINT = DESCRIPTOR.message_types_by_name['EndPoint']
_ALERTINFO = DESCRIPTOR.message_types_by_name['AlertInfo']
_PORTS = DESCRIPTOR.message_types_by_name['Ports']
_LINK = DESCRIPTOR.message_types_by_name['Link']
_POLICYINFO = DESCRIPTOR.message_types_by_name['PolicyInfo']
_LISTLINKSREQUEST = DESCRIPTOR.message_types_by_name['ListLinksRequest']
_LISTLINKSRESPONSE = DESCRIPTOR.message_types_by_name['ListLinksResponse']
_LENS = DESCRIPTOR.message_types_by_name['Lens']
_INSIGHT = DESCRIPTOR.message_types_by_name['Insight']
_LISTINSIGHTSREQUEST = DESCRIPTOR.message_types_by_name['ListInsightsRequest']
_LISTINSIGHTSRESPONSE = DESCRIPTOR.message_types_by_name['ListInsightsResponse']
_CREATEFORTIFYYAMLREQUEST = DESCRIPTOR.message_types_by_name['CreateFortifyYamlRequest']
_CREATEFORTIFYYAMLRESPONSE = DESCRIPTOR.message_types_by_name['CreateFortifyYamlResponse']
_LISTFORTIFYYAMLREQUEST = DESCRIPTOR.message_types_by_name['ListFortifyYamlRequest']
_LISTFORTIFYYAMLRESPONSE = DESCRIPTOR.message_types_by_name['ListFortifyYamlResponse']
_DELETEFORTIFYYAMLREQUEST = DESCRIPTOR.message_types_by_name['DeleteFortifyYamlRequest']
_LISTPOLICYANDENFORCEMENTSTATUSREQUEST = DESCRIPTOR.message_types_by_name['ListPolicyAndEnforcementStatusRequest']
_LISTPOLICYANDENFORCEMENTSTATUSRESPONSE = DESCRIPTOR.message_types_by_name['ListPolicyAndEnforcementStatusResponse']
_ARAALIFWKNOBS = DESCRIPTOR.message_types_by_name['AraaliFwKnobs']
_GETFIREWALLCONFIGREQUEST = DESCRIPTOR.message_types_by_name['GetFirewallConfigRequest']
_UPDATEFIREWALLCONFIGREQUEST = DESCRIPTOR.message_types_by_name['UpdateFirewallConfigRequest']
_FIREWALLCONFIGRESPONSE = DESCRIPTOR.message_types_by_name['FirewallConfigResponse']
_ARAALIUSER_ROLE = _ARAALIUSER.enum_types_by_name['Role']
_ARAALIAPIRESPONSE_RETURNCODE = _ARAALIAPIRESPONSE.enum_types_by_name['ReturnCode']
_ASSET_ASSETSTATE = _ASSET.enum_types_by_name['AssetState']
_ASSET_ASSETTYPE = _ASSET.enum_types_by_name['AssetType']
_ASSET_ASSETMODE = _ASSET.enum_types_by_name['AssetMode']
_VULNERABILITY_SEVERITY = _VULNERABILITY.enum_types_by_name['Severity']
_NONARAALIENDPOINT_ENDPOINTGROUP = _NONARAALIENDPOINT.enum_types_by_name['EndpointGroup']
_ALERTINFO_STATUS = _ALERTINFO.enum_types_by_name['Status']
_LINK_LINKDIRECTION = _LINK.enum_types_by_name['LinkDirection']
_LENS_LENSTYPE = _LENS.enum_types_by_name['LensType']
Tenant = _reflection.GeneratedProtocolMessageType('Tenant', (_message.Message,), {
  'DESCRIPTOR' : _TENANT,
  '__module__' : 'araali_api_service_pb2'
  # @@protoc_insertion_point(class_scope:araali_api_service.Tenant)
  })
_sym_db.RegisterMessage(Tenant)

AraaliUser = _reflection.GeneratedProtocolMessageType('AraaliUser', (_message.Message,), {
  'DESCRIPTOR' : _ARAALIUSER,
  '__module__' : 'araali_api_service_pb2'
  # @@protoc_insertion_point(class_scope:araali_api_service.AraaliUser)
  })
_sym_db.RegisterMessage(AraaliUser)

CreateTenantRequest = _reflection.GeneratedProtocolMessageType('CreateTenantRequest', (_message.Message,), {
  'DESCRIPTOR' : _CREATETENANTREQUEST,
  '__module__' : 'araali_api_service_pb2'
  # @@protoc_insertion_point(class_scope:araali_api_service.CreateTenantRequest)
  })
_sym_db.RegisterMessage(CreateTenantRequest)

CreateTenantResponse = _reflection.GeneratedProtocolMessageType('CreateTenantResponse', (_message.Message,), {
  'DESCRIPTOR' : _CREATETENANTRESPONSE,
  '__module__' : 'araali_api_service_pb2'
  # @@protoc_insertion_point(class_scope:araali_api_service.CreateTenantResponse)
  })
_sym_db.RegisterMessage(CreateTenantResponse)

DeleteTenantRequest = _reflection.GeneratedProtocolMessageType('DeleteTenantRequest', (_message.Message,), {
  'DESCRIPTOR' : _DELETETENANTREQUEST,
  '__module__' : 'araali_api_service_pb2'
  # @@protoc_insertion_point(class_scope:araali_api_service.DeleteTenantRequest)
  })
_sym_db.RegisterMessage(DeleteTenantRequest)

AddUserRequest = _reflection.GeneratedProtocolMessageType('AddUserRequest', (_message.Message,), {
  'DESCRIPTOR' : _ADDUSERREQUEST,
  '__module__' : 'araali_api_service_pb2'
  # @@protoc_insertion_point(class_scope:araali_api_service.AddUserRequest)
  })
_sym_db.RegisterMessage(AddUserRequest)

DeleteUserRequest = _reflection.GeneratedProtocolMessageType('DeleteUserRequest', (_message.Message,), {
  'DESCRIPTOR' : _DELETEUSERREQUEST,
  '__module__' : 'araali_api_service_pb2'
  # @@protoc_insertion_point(class_scope:araali_api_service.DeleteUserRequest)
  })
_sym_db.RegisterMessage(DeleteUserRequest)

AraaliAPIResponse = _reflection.GeneratedProtocolMessageType('AraaliAPIResponse', (_message.Message,), {
  'DESCRIPTOR' : _ARAALIAPIRESPONSE,
  '__module__' : 'araali_api_service_pb2'
  # @@protoc_insertion_point(class_scope:araali_api_service.AraaliAPIResponse)
  })
_sym_db.RegisterMessage(AraaliAPIResponse)

TimeSlice = _reflection.GeneratedProtocolMessageType('TimeSlice', (_message.Message,), {
  'DESCRIPTOR' : _TIMESLICE,
  '__module__' : 'araali_api_service_pb2'
  # @@protoc_insertion_point(class_scope:araali_api_service.TimeSlice)
  })
_sym_db.RegisterMessage(TimeSlice)

AssetFilter = _reflection.GeneratedProtocolMessageType('AssetFilter', (_message.Message,), {
  'DESCRIPTOR' : _ASSETFILTER,
  '__module__' : 'araali_api_service_pb2'
  # @@protoc_insertion_point(class_scope:araali_api_service.AssetFilter)
  })
_sym_db.RegisterMessage(AssetFilter)

ListAssetsRequest = _reflection.GeneratedProtocolMessageType('ListAssetsRequest', (_message.Message,), {
  'DESCRIPTOR' : _LISTASSETSREQUEST,
  '__module__' : 'araali_api_service_pb2'
  # @@protoc_insertion_point(class_scope:araali_api_service.ListAssetsRequest)
  })
_sym_db.RegisterMessage(ListAssetsRequest)

ListAssetsResponse = _reflection.GeneratedProtocolMessageType('ListAssetsResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTASSETSRESPONSE,
  '__module__' : 'araali_api_service_pb2'
  # @@protoc_insertion_point(class_scope:araali_api_service.ListAssetsResponse)
  })
_sym_db.RegisterMessage(ListAssetsResponse)

Capabilities = _reflection.GeneratedProtocolMessageType('Capabilities', (_message.Message,), {
  'DESCRIPTOR' : _CAPABILITIES,
  '__module__' : 'araali_api_service_pb2'
  # @@protoc_insertion_point(class_scope:araali_api_service.Capabilities)
  })
_sym_db.RegisterMessage(Capabilities)

Asset = _reflection.GeneratedProtocolMessageType('Asset', (_message.Message,), {
  'DESCRIPTOR' : _ASSET,
  '__module__' : 'araali_api_service_pb2'
  # @@protoc_insertion_point(class_scope:araali_api_service.Asset)
  })
_sym_db.RegisterMessage(Asset)

Vulnerability = _reflection.GeneratedProtocolMessageType('Vulnerability', (_message.Message,), {
  'DESCRIPTOR' : _VULNERABILITY,
  '__module__' : 'araali_api_service_pb2'
  # @@protoc_insertion_point(class_scope:araali_api_service.Vulnerability)
  })
_sym_db.RegisterMessage(Vulnerability)

AlertFilter = _reflection.GeneratedProtocolMessageType('AlertFilter', (_message.Message,), {
  'DESCRIPTOR' : _ALERTFILTER,
  '__module__' : 'araali_api_service_pb2'
  # @@protoc_insertion_point(class_scope:araali_api_service.AlertFilter)
  })
_sym_db.RegisterMessage(AlertFilter)

ListAlertsRequest = _reflection.GeneratedProtocolMessageType('ListAlertsRequest', (_message.Message,), {
  'DESCRIPTOR' : _LISTALERTSREQUEST,
  '__module__' : 'araali_api_service_pb2'
  # @@protoc_insertion_point(class_scope:araali_api_service.ListAlertsRequest)
  })
_sym_db.RegisterMessage(ListAlertsRequest)

ListAlertsResponse = _reflection.GeneratedProtocolMessageType('ListAlertsResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTALERTSRESPONSE,
  '__module__' : 'araali_api_service_pb2'
  # @@protoc_insertion_point(class_scope:araali_api_service.ListAlertsResponse)
  })
_sym_db.RegisterMessage(ListAlertsResponse)

AraaliEndpoint = _reflection.GeneratedProtocolMessageType('AraaliEndpoint', (_message.Message,), {
  'DESCRIPTOR' : _ARAALIENDPOINT,
  '__module__' : 'araali_api_service_pb2'
  # @@protoc_insertion_point(class_scope:araali_api_service.AraaliEndpoint)
  })
_sym_db.RegisterMessage(AraaliEndpoint)

Subnet = _reflection.GeneratedProtocolMessageType('Subnet', (_message.Message,), {
  'DESCRIPTOR' : _SUBNET,
  '__module__' : 'araali_api_service_pb2'
  # @@protoc_insertion_point(class_scope:araali_api_service.Subnet)
  })
_sym_db.RegisterMessage(Subnet)

NonAraaliClientEndpoint = _reflection.GeneratedProtocolMessageType('NonAraaliClientEndpoint', (_message.Message,), {
  'DESCRIPTOR' : _NONARAALICLIENTENDPOINT,
  '__module__' : 'araali_api_service_pb2'
  # @@protoc_insertion_point(class_scope:araali_api_service.NonAraaliClientEndpoint)
  })
_sym_db.RegisterMessage(NonAraaliClientEndpoint)

NonAraaliServerEndpoint = _reflection.GeneratedProtocolMessageType('NonAraaliServerEndpoint', (_message.Message,), {
  'DESCRIPTOR' : _NONARAALISERVERENDPOINT,
  '__module__' : 'araali_api_service_pb2'
  # @@protoc_insertion_point(class_scope:araali_api_service.NonAraaliServerEndpoint)
  })
_sym_db.RegisterMessage(NonAraaliServerEndpoint)

NonAraaliEndpoint = _reflection.GeneratedProtocolMessageType('NonAraaliEndpoint', (_message.Message,), {
  'DESCRIPTOR' : _NONARAALIENDPOINT,
  '__module__' : 'araali_api_service_pb2'
  # @@protoc_insertion_point(class_scope:araali_api_service.NonAraaliEndpoint)
  })
_sym_db.RegisterMessage(NonAraaliEndpoint)

EndPoint = _reflection.GeneratedProtocolMessageType('EndPoint', (_message.Message,), {
  'DESCRIPTOR' : _ENDPOINT,
  '__module__' : 'araali_api_service_pb2'
  # @@protoc_insertion_point(class_scope:araali_api_service.EndPoint)
  })
_sym_db.RegisterMessage(EndPoint)

AlertInfo = _reflection.GeneratedProtocolMessageType('AlertInfo', (_message.Message,), {
  'DESCRIPTOR' : _ALERTINFO,
  '__module__' : 'araali_api_service_pb2'
  # @@protoc_insertion_point(class_scope:araali_api_service.AlertInfo)
  })
_sym_db.RegisterMessage(AlertInfo)

Ports = _reflection.GeneratedProtocolMessageType('Ports', (_message.Message,), {
  'DESCRIPTOR' : _PORTS,
  '__module__' : 'araali_api_service_pb2'
  # @@protoc_insertion_point(class_scope:araali_api_service.Ports)
  })
_sym_db.RegisterMessage(Ports)

Link = _reflection.GeneratedProtocolMessageType('Link', (_message.Message,), {
  'DESCRIPTOR' : _LINK,
  '__module__' : 'araali_api_service_pb2'
  # @@protoc_insertion_point(class_scope:araali_api_service.Link)
  })
_sym_db.RegisterMessage(Link)

PolicyInfo = _reflection.GeneratedProtocolMessageType('PolicyInfo', (_message.Message,), {
  'DESCRIPTOR' : _POLICYINFO,
  '__module__' : 'araali_api_service_pb2'
  # @@protoc_insertion_point(class_scope:araali_api_service.PolicyInfo)
  })
_sym_db.RegisterMessage(PolicyInfo)

ListLinksRequest = _reflection.GeneratedProtocolMessageType('ListLinksRequest', (_message.Message,), {
  'DESCRIPTOR' : _LISTLINKSREQUEST,
  '__module__' : 'araali_api_service_pb2'
  # @@protoc_insertion_point(class_scope:araali_api_service.ListLinksRequest)
  })
_sym_db.RegisterMessage(ListLinksRequest)

ListLinksResponse = _reflection.GeneratedProtocolMessageType('ListLinksResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTLINKSRESPONSE,
  '__module__' : 'araali_api_service_pb2'
  # @@protoc_insertion_point(class_scope:araali_api_service.ListLinksResponse)
  })
_sym_db.RegisterMessage(ListLinksResponse)

Lens = _reflection.GeneratedProtocolMessageType('Lens', (_message.Message,), {
  'DESCRIPTOR' : _LENS,
  '__module__' : 'araali_api_service_pb2'
  # @@protoc_insertion_point(class_scope:araali_api_service.Lens)
  })
_sym_db.RegisterMessage(Lens)

Insight = _reflection.GeneratedProtocolMessageType('Insight', (_message.Message,), {
  'DESCRIPTOR' : _INSIGHT,
  '__module__' : 'araali_api_service_pb2'
  # @@protoc_insertion_point(class_scope:araali_api_service.Insight)
  })
_sym_db.RegisterMessage(Insight)

ListInsightsRequest = _reflection.GeneratedProtocolMessageType('ListInsightsRequest', (_message.Message,), {
  'DESCRIPTOR' : _LISTINSIGHTSREQUEST,
  '__module__' : 'araali_api_service_pb2'
  # @@protoc_insertion_point(class_scope:araali_api_service.ListInsightsRequest)
  })
_sym_db.RegisterMessage(ListInsightsRequest)

ListInsightsResponse = _reflection.GeneratedProtocolMessageType('ListInsightsResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTINSIGHTSRESPONSE,
  '__module__' : 'araali_api_service_pb2'
  # @@protoc_insertion_point(class_scope:araali_api_service.ListInsightsResponse)
  })
_sym_db.RegisterMessage(ListInsightsResponse)

CreateFortifyYamlRequest = _reflection.GeneratedProtocolMessageType('CreateFortifyYamlRequest', (_message.Message,), {
  'DESCRIPTOR' : _CREATEFORTIFYYAMLREQUEST,
  '__module__' : 'araali_api_service_pb2'
  # @@protoc_insertion_point(class_scope:araali_api_service.CreateFortifyYamlRequest)
  })
_sym_db.RegisterMessage(CreateFortifyYamlRequest)

CreateFortifyYamlResponse = _reflection.GeneratedProtocolMessageType('CreateFortifyYamlResponse', (_message.Message,), {
  'DESCRIPTOR' : _CREATEFORTIFYYAMLRESPONSE,
  '__module__' : 'araali_api_service_pb2'
  # @@protoc_insertion_point(class_scope:araali_api_service.CreateFortifyYamlResponse)
  })
_sym_db.RegisterMessage(CreateFortifyYamlResponse)

ListFortifyYamlRequest = _reflection.GeneratedProtocolMessageType('ListFortifyYamlRequest', (_message.Message,), {
  'DESCRIPTOR' : _LISTFORTIFYYAMLREQUEST,
  '__module__' : 'araali_api_service_pb2'
  # @@protoc_insertion_point(class_scope:araali_api_service.ListFortifyYamlRequest)
  })
_sym_db.RegisterMessage(ListFortifyYamlRequest)

ListFortifyYamlResponse = _reflection.GeneratedProtocolMessageType('ListFortifyYamlResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTFORTIFYYAMLRESPONSE,
  '__module__' : 'araali_api_service_pb2'
  # @@protoc_insertion_point(class_scope:araali_api_service.ListFortifyYamlResponse)
  })
_sym_db.RegisterMessage(ListFortifyYamlResponse)

DeleteFortifyYamlRequest = _reflection.GeneratedProtocolMessageType('DeleteFortifyYamlRequest', (_message.Message,), {
  'DESCRIPTOR' : _DELETEFORTIFYYAMLREQUEST,
  '__module__' : 'araali_api_service_pb2'
  # @@protoc_insertion_point(class_scope:araali_api_service.DeleteFortifyYamlRequest)
  })
_sym_db.RegisterMessage(DeleteFortifyYamlRequest)

ListPolicyAndEnforcementStatusRequest = _reflection.GeneratedProtocolMessageType('ListPolicyAndEnforcementStatusRequest', (_message.Message,), {
  'DESCRIPTOR' : _LISTPOLICYANDENFORCEMENTSTATUSREQUEST,
  '__module__' : 'araali_api_service_pb2'
  # @@protoc_insertion_point(class_scope:araali_api_service.ListPolicyAndEnforcementStatusRequest)
  })
_sym_db.RegisterMessage(ListPolicyAndEnforcementStatusRequest)

ListPolicyAndEnforcementStatusResponse = _reflection.GeneratedProtocolMessageType('ListPolicyAndEnforcementStatusResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTPOLICYANDENFORCEMENTSTATUSRESPONSE,
  '__module__' : 'araali_api_service_pb2'
  # @@protoc_insertion_point(class_scope:araali_api_service.ListPolicyAndEnforcementStatusResponse)
  })
_sym_db.RegisterMessage(ListPolicyAndEnforcementStatusResponse)

AraaliFwKnobs = _reflection.GeneratedProtocolMessageType('AraaliFwKnobs', (_message.Message,), {
  'DESCRIPTOR' : _ARAALIFWKNOBS,
  '__module__' : 'araali_api_service_pb2'
  # @@protoc_insertion_point(class_scope:araali_api_service.AraaliFwKnobs)
  })
_sym_db.RegisterMessage(AraaliFwKnobs)

GetFirewallConfigRequest = _reflection.GeneratedProtocolMessageType('GetFirewallConfigRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETFIREWALLCONFIGREQUEST,
  '__module__' : 'araali_api_service_pb2'
  # @@protoc_insertion_point(class_scope:araali_api_service.GetFirewallConfigRequest)
  })
_sym_db.RegisterMessage(GetFirewallConfigRequest)

UpdateFirewallConfigRequest = _reflection.GeneratedProtocolMessageType('UpdateFirewallConfigRequest', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEFIREWALLCONFIGREQUEST,
  '__module__' : 'araali_api_service_pb2'
  # @@protoc_insertion_point(class_scope:araali_api_service.UpdateFirewallConfigRequest)
  })
_sym_db.RegisterMessage(UpdateFirewallConfigRequest)

FirewallConfigResponse = _reflection.GeneratedProtocolMessageType('FirewallConfigResponse', (_message.Message,), {
  'DESCRIPTOR' : _FIREWALLCONFIGRESPONSE,
  '__module__' : 'araali_api_service_pb2'
  # @@protoc_insertion_point(class_scope:araali_api_service.FirewallConfigResponse)
  })
_sym_db.RegisterMessage(FirewallConfigResponse)

_ARAALIAPI = DESCRIPTOR.services_by_name['AraaliAPI']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\020proto.araali.apiB\017APIServiceProtoP\001Z\034golang/v2/araali_api_service'
  _LINKSTATE._serialized_start=6997
  _LINKSTATE._serialized_end=7087
  _FORTIFYYAMLTYPE._serialized_start=7089
  _FORTIFYYAMLTYPE._serialized_end=7174
  _TENANT._serialized_start=81
  _TENANT._serialized_end=122
  _ARAALIUSER._serialized_start=125
  _ARAALIUSER._serialized_end=255
  _ARAALIUSER_ROLE._serialized_start=228
  _ARAALIUSER_ROLE._serialized_end=255
  _CREATETENANTREQUEST._serialized_start=257
  _CREATETENANTREQUEST._serialized_end=322
  _CREATETENANTRESPONSE._serialized_start=324
  _CREATETENANTRESPONSE._serialized_end=447
  _DELETETENANTREQUEST._serialized_start=449
  _DELETETENANTREQUEST._serialized_end=514
  _ADDUSERREQUEST._serialized_start=516
  _ADDUSERREQUEST._serialized_end=622
  _DELETEUSERREQUEST._serialized_start=624
  _DELETEUSERREQUEST._serialized_end=733
  _ARAALIAPIRESPONSE._serialized_start=736
  _ARAALIAPIRESPONSE._serialized_end=889
  _ARAALIAPIRESPONSE_RETURNCODE._serialized_start=838
  _ARAALIAPIRESPONSE_RETURNCODE._serialized_end=889
  _TIMESLICE._serialized_start=891
  _TIMESLICE._serialized_end=996
  _ASSETFILTER._serialized_start=998
  _ASSETFILTER._serialized_end=1125
  _LISTASSETSREQUEST._serialized_start=1128
  _LISTASSETSREQUEST._serialized_end=1312
  _LISTASSETSRESPONSE._serialized_start=1314
  _LISTASSETSRESPONSE._serialized_end=1434
  _CAPABILITIES._serialized_start=1436
  _CAPABILITIES._serialized_end=1472
  _ASSET._serialized_start=1475
  _ASSET._serialized_end=2206
  _ASSET_ASSETSTATE._serialized_start=1971
  _ASSET_ASSETSTATE._serialized_end=2022
  _ASSET_ASSETTYPE._serialized_start=2024
  _ASSET_ASSETTYPE._serialized_end=2090
  _ASSET_ASSETMODE._serialized_start=2092
  _ASSET_ASSETMODE._serialized_end=2190
  _VULNERABILITY._serialized_start=2209
  _VULNERABILITY._serialized_end=2391
  _VULNERABILITY_SEVERITY._serialized_start=2326
  _VULNERABILITY_SEVERITY._serialized_end=2391
  _ALERTFILTER._serialized_start=2394
  _ALERTFILTER._serialized_end=2679
  _LISTALERTSREQUEST._serialized_start=2682
  _LISTALERTSREQUEST._serialized_end=2831
  _LISTALERTSRESPONSE._serialized_start=2834
  _LISTALERTSRESPONSE._serialized_end=2974
  _ARAALIENDPOINT._serialized_start=2977
  _ARAALIENDPOINT._serialized_end=3160
  _SUBNET._serialized_start=3162
  _SUBNET._serialized_end=3204
  _NONARAALICLIENTENDPOINT._serialized_start=3206
  _NONARAALICLIENTENDPOINT._serialized_end=3275
  _NONARAALISERVERENDPOINT._serialized_start=3278
  _NONARAALISERVERENDPOINT._serialized_end=3407
  _NONARAALIENDPOINT._serialized_start=3410
  _NONARAALIENDPOINT._serialized_end=3719
  _NONARAALIENDPOINT_ENDPOINTGROUP._serialized_start=3656
  _NONARAALIENDPOINT_ENDPOINTGROUP._serialized_end=3711
  _ENDPOINT._serialized_start=3722
  _ENDPOINT._serialized_end=3855
  _ALERTINFO._serialized_start=3858
  _ALERTINFO._serialized_end=4060
  _ALERTINFO_STATUS._serialized_start=4010
  _ALERTINFO_STATUS._serialized_end=4060
  _PORTS._serialized_start=4062
  _PORTS._serialized_end=4115
  _LINK._serialized_start=4118
  _LINK._serialized_end=4686
  _LINK_LINKDIRECTION._serialized_start=4540
  _LINK_LINKDIRECTION._serialized_end=4678
  _POLICYINFO._serialized_start=4688
  _POLICYINFO._serialized_end=4774
  _LISTLINKSREQUEST._serialized_start=4777
  _LISTLINKSREQUEST._serialized_end=4928
  _LISTLINKSRESPONSE._serialized_start=4930
  _LISTLINKSRESPONSE._serialized_end=5047
  _LENS._serialized_start=5050
  _LENS._serialized_end=5355
  _LENS_LENSTYPE._serialized_start=5250
  _LENS_LENSTYPE._serialized_end=5355
  _INSIGHT._serialized_start=5357
  _INSIGHT._serialized_end=5450
  _LISTINSIGHTSREQUEST._serialized_start=5452
  _LISTINSIGHTSREQUEST._serialized_end=5531
  _LISTINSIGHTSRESPONSE._serialized_start=5533
  _LISTINSIGHTSRESPONSE._serialized_end=5659
  _CREATEFORTIFYYAMLREQUEST._serialized_start=5662
  _CREATEFORTIFYYAMLREQUEST._serialized_end=5878
  _CREATEFORTIFYYAMLRESPONSE._serialized_start=5880
  _CREATEFORTIFYYAMLRESPONSE._serialized_end=5987
  _LISTFORTIFYYAMLREQUEST._serialized_start=5989
  _LISTFORTIFYYAMLREQUEST._serialized_end=6113
  _LISTFORTIFYYAMLRESPONSE._serialized_start=6115
  _LISTFORTIFYYAMLRESPONSE._serialized_end=6216
  _DELETEFORTIFYYAMLREQUEST._serialized_start=6218
  _DELETEFORTIFYYAMLREQUEST._serialized_end=6311
  _LISTPOLICYANDENFORCEMENTSTATUSREQUEST._serialized_start=6314
  _LISTPOLICYANDENFORCEMENTSTATUSREQUEST._serialized_end=6456
  _LISTPOLICYANDENFORCEMENTSTATUSRESPONSE._serialized_start=6458
  _LISTPOLICYANDENFORCEMENTSTATUSRESPONSE._serialized_end=6535
  _ARAALIFWKNOBS._serialized_start=6538
  _ARAALIFWKNOBS._serialized_end=6711
  _GETFIREWALLCONFIGREQUEST._serialized_start=6713
  _GETFIREWALLCONFIGREQUEST._serialized_end=6772
  _UPDATEFIREWALLCONFIGREQUEST._serialized_start=6774
  _UPDATEFIREWALLCONFIGREQUEST._serialized_end=6886
  _FIREWALLCONFIGRESPONSE._serialized_start=6888
  _FIREWALLCONFIGRESPONSE._serialized_end=6995
  _ARAALIAPI._serialized_start=7177
  _ARAALIAPI._serialized_end=8674
# @@protoc_insertion_point(module_scope)
